/*
	Ramp Spawning Script
	--------------------------------------------------
	This is a script used for LU object testing. It spawns a ramp in front of the player
	when they press a certain key. This file takes care of object spawning and storing
	and it includes the functions called by the clientside script.
	
	Author: Juppi
*/

const RAMP_OBJECT = 1378; // This needs changing if the game is not GTA3!

objects <- array( GetMaxPlayers(), -1 );


/* This function is called by the clients */
function SpawnRamp( id, boost )
{
	local plr = FindPlayer( id );
	if ( plr )
	{
		local pos = plr.Pos;
		local rot = plr.Angle, rad = rot * PI / 180.0;
		
		/* Calculate the position of the ramp after rotation */
		local x = pos.x, y = pos.y;
		local x2 = x + 1.0 * cos(rad) - 25.0 * sin(rad);
		local y2 = y + 1.0 * sin(rad) + 25.0 * cos(rad);
		
		if ( objects[id] != -1 )
		{
			local obj = FindObject( objects[id] );
			if ( obj )
			{
				obj.Pos = Vector( x2, y2, pos.z - 0.5 );
				obj.Angle = Vector( 0.0, 0.0, rot + 270.0 );
			}
		}
		else
		{
			local obj = CreateObject( RAMP_OBJECT, Vector( x2, y2, pos.z ), Vector( 0.0, 0.0, rot + 270.0 ) );
			if ( obj )
			{
				objects[id] = obj.ID;
			}
		}
		
		if ( boost ) VehicleBoost( plr );
	}
}

/* This function gives the player's vehicle a 50% speed boost */
function VehicleBoost( plr )
{
	local veh = plr.Vehicle;
	if ( veh )
	{
		local vel = veh.Velocity;
		vel.x *= 1.5;
		vel.y *= 1.5;
		vel.z *= 1.5;
		
		veh.Velocity = vel;
	}
}

/* Clear the ramp when the player leaves */
function onPlayerPart( plr, reason )
{
	local id = plr.ID;
	if ( objects[id] != -1 )
	{
		local obj = FindObject( objects[id] );
		if ( obj )
		{
			obj.Remove();
			objects[id] = -1;
		}
	}
	
	return 1;
}
